==> vuejs-1.0.19.tgz: package/docs/element-ui/grid.md <==
## 基于 element-ui 布局组件封装扩展

### 组件文件

| 组件名称 | 组件路径 | 组件说明
| :--- | :--- | :--- |
| nftn-el-grid | /components/element-ui/grid/main.vue | 网格组件 |

### 依赖内容
| 依赖名称 | 依赖路径 | 依赖说明
| :--- | :--- | :--- |
| el-row<br>el-col | http://element.eleme.io/#/zh-CN/component/layout | element-ui 布局组件 |

### props
| 参数名称 | 参数类型 | 参数说明 | 可选值 | 默认值 |
| :--- | :--- | :--- | :--- | :--- |
| --- __显示相关__ --- |
| rows ^2017-06-20^ | Array | 矩阵数据指示行列情况 | 参考下面 _rows | `[[24]]` |
| gap ^2017-06-20^ | Number | 栅格间距 | 参考下面 _gap | `0` |
| gaps ^2017-06-20^ | [Array, Object] | 栅格间距(也可对应每一行进行设置) | 参考下面 _gaps | `[]` |
| --- __其他__ --- |
| configs ^2017-06-20^ | Object | 所有 props 集合 | 参考下面 _configs | {} |

___configs 代码结构___
```javascript
    let _base = {
        span: Number,
        offset: Number
    };
    let _col = Object.assign(_base, {
        xs: Number || _base,
        sm: Number || _base,
        md: Number || _base,
        lg: Number || _base
    });
    let _gap = Number || 0;
    let _gaps = [Number, ...] || { (index): Number, ... };
    let _rows = [
        [Number, _col, ...],
        {
            cols: [Number, _col],
            gap: _gap,
            gaps: _gaps
        }
    ];
    let _configs = {
        rows: _rows,
        gap: _gap,
        gaps: _gaps
    };
```

### slots & demo
___grid-' + {row.index} + '-' + {col.index} // 每一行每一列都有一个内容分发可配置___
``` html
<div id="demo" class="nftn-demo">
    <nftn-el-grid v-bind:configs="grid">
        <template slot="grid-3-3">替换 3-3 的位置替换 3-3 3-3 的位置</template>
    </nftn-el-grid>
    <a href="javascript:;" v-on:click="change">change</a>
</div>

<script type="text/javascript">
    new Vue('demo', {
        data: {
            grid: {
                gap: 10, // 默认栅栏间距 10 (padding: 0px 5px;)
                gaps: {
                    2: 50 // 第三行栅栏间距为 50px (padding: 0px 25px;)
                },
                rows: [ // 建议每行栅栏设置划分综合不要超过 24
                    [12, 8, 4],
                    [4, 4, 3, 3, 2, 6, 1, 1],
                    [12, 12],
                    [4, 8, 4, 6, { span: 1, offset: 1 }], // '6'的位置被 slot="grid-3-3" 改写了
                    [3, { span: 10, offset: 2 }],
                    [{ span: 5, offset: 2 }],
                    { cols: [5, { span: 2, offset: 2 }], gap: 30 }
                ]
            }
        }
    });
</script>
```

### 后期计划
- 设置行间距 lending? lendings?

==> vuejs-1.0.28.tgz: package/docs/element-ui/grid.md <==
## 基于 element-ui 布局组件封装扩展

### 组件文件

| 组件名称 | 组件路径 | 组件说明
| :--- | :--- | :--- |
| nftn-el-grid | /components/element-ui/grid/main.vue | 网格组件 |

### 依赖内容
| 依赖名称 | 依赖路径 | 依赖说明
| :--- | :--- | :--- |
| el-row + el-col | http://element.eleme.io/#/zh-CN/component/layout | element-ui 布局组件 |

### props
| 参数名称 | 参数类型 | 参数说明 | 可选值 | 默认值 |
| :--- | :--- | :--- | :--- | :--- |
| --- __显示相关__ --- |
| rows | Array | 矩阵数据指示行列情况 | 参考下面 _rows | `[[24]]` |
| gap | Number | 栅格间距 | 参考下面 _gap | `0` |
| gaps | [Array, Object] | 栅格间距(也可对应每一行进行设置) | 参考下面 _gaps | `[]` |
| --- __其他__ --- |
| configs | Object | 所有 props 集合 | 参考下面 _configs | {} |

___configs 代码结构___
```javascript
    let _base = {
        span: Number,
        offset: Number
    };
    let _col = Object.assign(_base, {
        xs: Number || _base,
        sm: Number || _base,
        md: Number || _base,
        lg: Number || _base
    });
    let _gap = Number || 0;
    let _gaps = [Number, ...] || { (index): Number, ... };
    let _rows = [
        [Number, _col, ...],
        {
            cols: [Number, _col],
            gap: _gap,
            gaps: _gaps
        }
    ];
    let _configs = {
        rows: _rows,
        gap: _gap,
        gaps: _gaps
    };
```

### slots & demo
___grid-' + {row.index} + '-' + {col.index} // 每一行每一列都有一个内容分发可配置___
``` html
<div id="demo" class="nftn-demo">
    <nftn-el-grid v-bind:configs="grid">
        <template slot="grid-3-3">替换 3-3 的位置替换 3-3 3-3 的位置</template>
    </nftn-el-grid>
    <a href="javascript:;" v-on:click="change">change</a>
</div>

<script type="text/javascript">
    new Vue('demo', {
        data: {
            grid: {
                gap: 10, // 默认栅栏间距 10 (padding: 0px 5px;)
                gaps: {
                    2: 50 // 第三行栅栏间距为 50px (padding: 0px 25px;)
                },
                rows: [ // 建议每行栅栏设置划分综合不要超过 24
                    [12, 8, 4],
                    [4, 4, 3, 3, 2, 6, 1, 1],
                    [12, 12],
                    [4, 8, 4, 6, { span: 1, offset: 1 }], // '6'的位置被 slot="grid-3-3" 改写了
                    [3, { span: 10, offset: 2 }],
                    [{ span: 5, offset: 2 }],
                    { cols: [5, { span: 2, offset: 2 }], gap: 30 }
                ]
            }
        }
    });
</script>
```

### 后续设想
- [ ] 20170720 设置行间距 lending? lendings?
